package com.lpsfr.lib.utils;

import android.app.Activity;
import android.app.PendingIntent;
import android.content.Intent;
import android.net.Uri;

import androidx.annotation.Nullable;
import androidx.core.content.FileProvider;

import java.io.BufferedOutputStream;
import java.io.File;
import java.io.FileOutputStream;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

public class FileHelper {
    private final static int SHARE_CODE = 1235;

    @Nullable
    private static Result<Throwable> waitingResult = null;

    public static void zip(File zipFile, String name, String content) {
        try {
            ZipOutputStream out = new ZipOutputStream(new BufferedOutputStream(new FileOutputStream(zipFile)));

            byte[] data = content.getBytes();

            ZipEntry entry = new ZipEntry(name);
            out.putNextEntry(entry);
            int count = data.length;

            out.write(data, 0, count);
            out.close();
        } catch (Throwable exception) {
            exception.printStackTrace();
        }
    }

    // removed @Override temporarily just to get it working on different versions of RN
    public static void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode == SHARE_CODE && null != waitingResult) {
            if (resultCode == Activity.RESULT_CANCELED) {
                try {
                    throw new PendingIntent.CanceledException("action canceled");
                }catch(Throwable e) {
                    waitingResult.onResult(e);
                }
            } else if (resultCode == Activity.RESULT_OK) {
                waitingResult.onResult(null);
            }
        }
    }

    public static void shareInReports(Activity activity,
                                           String authority,
                                           File zipFile,
                                           String mimeType,
                                           Result<Throwable> result) {
        try {

            Uri contentUri = FileProvider.getUriForFile(activity, authority, zipFile);

            waitingResult = result;
            if (contentUri != null) {
                Intent shareIntent = new Intent();
                shareIntent.setAction(Intent.ACTION_SEND);
                shareIntent.addFlags(Intent.FLAG_GRANT_READ_URI_PERMISSION); // temp permission for receiving app to read this file
                shareIntent.setDataAndType(contentUri, activity.getContentResolver().getType(contentUri));
                shareIntent.putExtra(Intent.EXTRA_STREAM, contentUri);
                shareIntent.setType(mimeType);
                activity.startActivityForResult(Intent.createChooser(shareIntent, "Choose an app"), SHARE_CODE);
            } else {
                throw new IllegalStateException("contentUri is null");
            }
            //result.onResult(null);
        } catch (Throwable e) {
            waitingResult= null;
            result.onResult(e);
        }
    }
}
