package com.lpsfr.lib.utils;

import android.content.Context;
import android.util.Log;

import java.io.BufferedReader;
import java.io.File;
import java.io.IOException;
import java.io.InputStreamReader;
import java.util.ArrayList;
import java.util.concurrent.locks.ReentrantLock;

public class Logcat {

    private static final String TAG = Logcat.class.getSimpleName();
    private static final Async async = new Async("LogcatAsync");
    private final long size;
    private ArrayList<String> lines = new ArrayList<>();

    private boolean isRunning = false;
    private Process process;
    private BufferedReader bufferedReader;
    private Thread thread;

    private ReentrantLock lock = new ReentrantLock();

    public Logcat(long size) {
        this.size = size;
    }

    public void start() {
        if (isRunning) return;

        isRunning = true;
        async.run(() -> {
            thread = new Thread(run());
            thread.start();
        });
    }

    public void stop() {
        if (!isRunning) return;

        async.run(() -> {
            try {
                bufferedReader.close();
            } catch (Throwable e) {
                e.printStackTrace();
            }
            bufferedReader = null;
            try {
                process.destroy();
            } catch (Throwable e) {
                e.printStackTrace();
            }
            process = null;
            try {
                thread.stop();
            } catch (Throwable e) {
                e.printStackTrace();
            }
            thread = null;

            isRunning = false;
        });

    }

    public boolean isRunning() {
        return isRunning;
    }

    public void toFile(Context context, Result<File> onResult) {
       async.run(() -> {

            File tmpDir = context.getCacheDir();
            File reports = new File(tmpDir, "reports");
            if (!reports.exists()) reports.mkdir();
            File zipFile = new File(reports, "report.zip");

            lock();
            StringBuilder buffer = new StringBuilder();
            for (String line : lines) {
                buffer.append(line).append("\n");
            }
            Log.d(TAG, "toFile: " + lines.size());
            unlock();

            FileHelper.zip(zipFile, "logs.txt", buffer.toString());

            onResult.onResult(zipFile);
        });
    }

    private Runnable run() {
        return () -> {
            isRunning = true;
            try {
                process = Runtime.getRuntime().exec("logcat");
                bufferedReader = new BufferedReader(
                        new InputStreamReader(process.getInputStream()));

                String line;
                while (null != process
                        && null != bufferedReader
                        && null != (line = bufferedReader.readLine())) {
                    lock();
                    lines.add(line);
                    unlock();
                }

                while (lines.size() > size) {
                    lines.remove(0);
                }

                isRunning = false;

            } catch (IOException e) {
                isRunning = false;
                e.printStackTrace();
            }
        };
    }

    private void lock() {
        try {
            lock.lock();
        } catch (Throwable e) {

        }
    }

    private void unlock() {
        try {
            if (lock.isLocked()) lock.unlock();
        } catch (Throwable e) {

        }
    }

}
