import { Argument, RawType } from "./Types";
var Column = /** @class */ (function () {
    function Column(_name) {
        var _this = this;
        this._name = _name;
        this._type = RawType.Integer;
        this._primary = false;
        this._foreign = false;
        this._def = "NULL";
        this._index = false;
        this.autoincrement = "AUTOINCREMENT";
        this.transformIntoTable = function () { return null; };
        this.transformFromTable = function () { return null; };
        this.name = function () { return _this._name; };
        this.isPrimary = function () { return !!_this._primary; };
    }
    Column.prototype.fromDecorator = function (decorator) {
        if (!!decorator.primary)
            this.primary();
        if (!!decorator.index)
            this.index();
        if (!!decorator.foreign)
            this.foreign();
        this.transformIntoTable = decorator.type.transformIntoTable;
        this.transformFromTable = decorator.type.transformFromTable;
        if (decorator.option) {
            switch (decorator.option) {
                case Argument.DefaultNonNull:
                    this.defaultNotNull();
                    break;
                case Argument.DefaultNull:
                    this.defaultNull();
                    break;
                case Argument.DefaultZero:
                    this.defaultZero();
                    break;
                default:
            }
        }
        if (decorator.type) {
            this._type = decorator.type.type;
        }
        return this;
    };
    Column.prototype.foreign = function () {
        this._foreign = true;
        return this;
    };
    Column.prototype.primary = function () {
        this._primary = true;
        return this.defaultNotNull();
    };
    Column.prototype.toString = function () {
        var result = "";
        //if(this._primary) result += " AUTOINCREMENT PRIMARY KEY";
        //if(this._primary) result += " AUTO_INCREMENT PRIMARY KEY";
        if (this._primary) {
            result += "`" + this.name() + "` " + this._type + " PRIMARY KEY AUTOINCREMENT ";
        }
        else {
            result = "`" + this.name() + "` " + this._type + " " + this._def;
        }
        return result;
    };
    Column.prototype.migrate = function () {
        return "`" + this.name() + "` " + this._type + " DEFAULT " + this._def;
    };
    Column.prototype.isIndex = function () {
        return this._index;
    };
    Column.prototype.createIndex = function () {
        return "(" + this.name() + ")"; //\`${this.name()}\`
    };
    Column.prototype.defaultZero = function () {
        this._def = "0";
        return this;
    };
    Column.prototype.defaultNull = function () {
        this._def = "NULL";
        return this;
    };
    Column.prototype.defaultNotNull = function () {
        this._def = "NOT NULL";
        return this;
    };
    Column.prototype.str = function () {
        this._type = RawType.Text;
        return this;
    };
    Column.prototype.integer = function () {
        this._type = RawType.Integer;
        return this;
    };
    Column.prototype.bool = function () {
        this._type = RawType.Bool;
        return this;
    };
    Column.prototype.index = function () {
        this._index = true;
        return this;
    };
    return Column;
}());
export default Column;
//# sourceMappingURL=Column.js.map