import { ColumnAnnotation } from '../helpers/Types';
import { UUIDable } from '../table/UUIDable';
import DbDescriptor, { BindTogether } from '../table/DbDescriptor';
import { Transaction } from "../helpers/Query";
import { LoggerObject } from '../../utils/Logger';
export interface ColumnDecorator {
    field: string;
    column: ColumnAnnotation;
}
export interface GenericInterface<T extends Abstract<UUIDable, T>> {
    new (something: any): T;
}
export interface SelectChildren<T extends Abstract<UUIDable, T>, K extends GenericInterface<T>> {
    (klass: K, parent_id: number): Promise<T[]>;
}
export interface CreateOrUpdate {
    (instance: Abstract<UUIDable, any>): Promise<Abstract<UUIDable, any>>;
}
export declare abstract class Abstract<TYPE extends UUIDable, SELF extends Abstract<TYPE, SELF>> {
    protected logger: LoggerObject;
    private __this?;
    private event;
    descriptor?: DbDescriptor;
    id: number | undefined;
    parent_id: number | undefined;
    uuid: string;
    deleted: boolean;
    locally_updated: boolean;
    optional_verification_validated: boolean;
    version: string;
    date: Date;
    date_unknown: boolean;
    db_values?: TYPE;
    constructor(name: string, db_values?: TYPE);
    private getOrCreateDbDescriptor;
    getDate(): Date | undefined;
    private enforceDate;
    merge(json: any, override?: boolean): this;
    private findInJson;
    init(instance: any): DbDescriptor;
    populate(): Promise<any>;
    private _log;
    log(enable: boolean): void;
    private transaction;
    protected _save(transaction: Transaction, recursive?: boolean): Promise<this>;
    save(recursive?: boolean): Promise<this>;
    fireUpdate(): void;
    protected populateChildrenForKey(key: string, klass: GenericInterface<any>): Promise<this>;
    json(include_local?: boolean): any;
    protected assets_key: () => string[];
    is_verification: (key: string) => boolean;
    verification_keys(): (keyof SELF)[];
    full_json(include_local?: boolean, exclude_assets?: boolean): any;
    clone(): any;
    protected keys(): (keyof SELF)[];
    private allKeys;
    protected from(from?: any): void;
    default_key: string | undefined;
    getDescriptionKeys(is_simulation?: boolean): (keyof SELF)[];
    protected annotated_columns(): BindTogether<ColumnAnnotation>[];
    protected annotated_children(): BindTogether<GenericInterface<Abstract<any, any>>>[];
    onUpdate(listener: (obj: this) => void): () => void;
    addListener(event: string, listener: (obj: this) => void): () => void;
}
