import { Abstract } from "./Abstract";
import { UUIDable } from "../table/UUIDable";
import { State } from "../helpers/State";
import BuildingAsset from "./BuildingAsset";
import BuildingItem from "./BuildingItem";
import { Position } from "../../webservice/Weather";
import { ProtectionLevel } from "../helpers/ProtectionLevel";
import { Cd } from "../helpers/Cd";
import { RiskFire } from "../helpers/RiskFire";
import { Danger } from "../helpers/Danger";
import { Occupation } from "../helpers/Occupation";
import { ServiceEntrant } from "../helpers/ServiceEntrant";
import { ServiceType } from "../helpers/ServiceType";
import ElectricalGroundingComponent from "./ElectricalGroundingComponent";
import IncomingServiceComponent from "./IncomingServiceComponent";
export interface BuildingParams extends UUIDable {
    name?: string;
    description?: string;
    latitudes?: string;
    longitudes?: string;
    height?: number;
    width?: number;
    depth?: number;
    state?: State;
    state_description?: string;
    protection_level?: ProtectionLevel;
    delta_latitude_meter?: number;
    delta_longitude_meter?: number;
}
export default class Building extends Abstract<BuildingParams, Building> implements BuildingParams {
    assets: BuildingAsset[];
    validAssets(): BuildingAsset[];
    items: BuildingItem[];
    validItems(): BuildingItem[];
    electricalGroundings: ElectricalGroundingComponent[];
    validElectricalGroundings(): ElectricalGroundingComponent[];
    incomingServices: IncomingServiceComponent[];
    validIncomingServices(): IncomingServiceComponent[];
    name: string | undefined;
    height: number | undefined;
    width: number | undefined;
    depth: number | undefined;
    description: string;
    latitudes: string | undefined;
    longitudes: string | undefined;
    state: State;
    state_description: string | undefined;
    protection_level: ProtectionLevel;
    environment_comment: string | undefined;
    cd: Cd;
    risk_fire: RiskFire;
    danger: Danger;
    occupation: Occupation;
    service1_comment: string | undefined;
    service1: ServiceEntrant;
    /**
     * @deprecated
     */
    service1_type: ServiceType;
    /**
     * @deprecated
     */
    service2_comment: string | undefined;
    /**
     * @deprecated
     */
    service2: ServiceEntrant;
    /**
     * @deprecated
     */
    service2_type: ServiceType;
    unacceptable_loss: ServiceType;
    delta_latitude_meter: number;
    delta_longitude_meter: number;
    constructor(values: BuildingParams);
    color(index: number): string;
    points(): Position[];
    protected assets_key: () => string[];
    getDescriptionKeys(is_simulation?: boolean): (keyof Building)[];
    private protection;
    getUnacceptableLoss(): ServiceType;
    getStructure: (ng: number) => {
        surface: number;
        Adp: number;
        Adglobal: number;
        Ad: number;
        ND: number;
    };
    getRisks: (ng: number) => {
        level_1: {
            protection_level: ProtectionLevel;
            isRT1Valid: boolean;
            isRT2Valid: boolean;
            isRT3Valid: boolean;
            valid: boolean;
        };
        level_2: {
            protection_level: ProtectionLevel;
            isRT1Valid: boolean;
            isRT2Valid: boolean;
            isRT3Valid: boolean;
            valid: boolean;
        };
        level_3: {
            protection_level: ProtectionLevel;
            isRT1Valid: boolean;
            isRT2Valid: boolean;
            isRT3Valid: boolean;
            valid: boolean;
        };
        level_4: {
            protection_level: ProtectionLevel;
            isRT1Valid: boolean;
            isRT2Valid: boolean;
            isRT3Valid: boolean;
            valid: boolean;
        };
        none: {
            protection_level: ProtectionLevel;
            isRT1Valid: boolean;
            isRT2Valid: boolean;
            isRT3Valid: boolean;
            valid: boolean;
        };
    };
    getServices: (ng: number) => {
        Cd: any;
        ND: number;
        AI: any;
        NI: number;
        PI_level_1: any;
        PI_level_2: any;
        PI_level_3: any;
        PI_level_4: any;
        PI_level_unknown: any;
        hz: any;
        rf: any;
        Lf1: any;
        LD1: number;
        LI1: number;
        Lf2: number;
        LD2: number;
        LI2: number;
        LD3: number;
        LI3: number;
        PD_level_1: number;
        PD_level_2: number;
        PD_level_3: number;
        PD_level_4: number;
        PD_level_unknown: number;
    };
    /**
     * Get the protection level. Can be 1 to 4, unknown is no need for protection.
     * undefined means that an analysis needs to be done
     * @param ng
     * @returns
     */
    getTheoricalProtectionLevel: (ng: number) => ProtectionLevel | undefined;
    setDelta(latitude: number, longitude: number): void;
    deltaMeter(): {
        latitude: number;
        longitude: number;
    };
    deltaKm(): {
        latitude: number;
        longitude: number;
    };
}
