var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { Abstract } from "./Abstract";
import { Argument, TypeText, TypeReal } from "../helpers/Types";
import { column, children } from "../helpers/Decorators";
import { State, TypeStateType } from "../helpers/State";
import BuildingAsset from "./BuildingAsset";
import BuildingItem from "./BuildingItem";
import { ProtectionLevel, TypeProtectionLevel } from "../helpers/ProtectionLevel";
import Protection from "../../utils/Protection";
import { TypeCd, Cd } from "../helpers/Cd";
import { TypeRiskFire, RiskFire } from "../helpers/RiskFire";
import { TypeDanger, Danger } from "../helpers/Danger";
import { TypeOccupation, Occupation } from "../helpers/Occupation";
import { TypeServiceEntrant, ServiceEntrant } from "../helpers/ServiceEntrant";
import { TypeServiceType, ServiceType } from "../helpers/ServiceType";
import { distinctsAbstract } from "../../utils/Array";
import ElectricalGroundingComponent from "./ElectricalGroundingComponent";
import IncomingServiceComponent from "./IncomingServiceComponent";
var colors = [
    "#00ffff",
    "#008b8b",
    "#8b008b",
    "#556b2f",
    "#bdb76b",
    "#ff8c00",
    "#9932cc",
    "#006400",
    "#e9967a",
    "#9400d3",
    "#ffd700",
    "#008000",
    "#4b0082",
    "#f0e68c",
    "#add8e6",
    "#90ee90",
    "#ffb6c1",
    "#ffffe0",
    "#00ff00",
    "#808000",
    "#ffa500",
    "#ffc0cb",
    "#ffffff",
];
var Building = /** @class */ (function (_super) {
    __extends(Building, _super);
    function Building(values) {
        var _this = _super.call(this, "Building", values) || this;
        _this.assets = [];
        _this.items = [];
        _this.electricalGroundings = [];
        _this.incomingServices = [];
        _this.name = "";
        _this.height = 0;
        _this.width = 0;
        _this.depth = 0;
        _this.description = "";
        _this.latitudes = "";
        _this.longitudes = "";
        _this.state = State.DEFECTIVE;
        _this.state_description = "";
        _this.protection_level = ProtectionLevel.UNKNOWN;
        _this.environment_comment = "";
        _this.cd = Cd.HIGHER;
        _this.risk_fire = RiskFire.STANDARD;
        _this.danger = Danger.NO_DANGER;
        _this.occupation = Occupation.NO_OCCUPATION;
        _this.service1_comment = "";
        _this.service1 = ServiceEntrant.NONE;
        /**
         * @deprecated
         */
        _this.service1_type = ServiceType.NONE;
        /**
         * @deprecated
         */
        _this.service2_comment = "";
        /**
         * @deprecated
         */
        _this.service2 = ServiceEntrant.NONE;
        /**
         * @deprecated
         */
        _this.service2_type = ServiceType.NONE;
        _this.unacceptable_loss = ServiceType.NONE;
        _this.delta_latitude_meter = 0;
        _this.delta_longitude_meter = 0;
        _this.assets_key = function () { return ["assets"]; };
        _this.protection = function (ng) {
            var maxHeight = _this.height || 0;
            _this.validItems().forEach(function (sub) {
                var delta = sub.delta_height || 0;
                //var height = sub.height || 0;
                var height = _this.height || 0;
                if (delta + height > maxHeight)
                    maxHeight = delta + height;
            });
            return new Protection(ng, _this.width || 0, _this.depth || 0, _this.height || 0, maxHeight, _this.cd, _this.risk_fire, _this.danger, _this.occupation, _this.service1, 
            //this.service1_type,
            //this.service2,
            //this.service2_type,
            //0,
            _this.getUnacceptableLoss());
        };
        _this.getStructure = function (ng) {
            var protection = _this.protection(ng);
            return protection.calculs_structure();
        };
        _this.getRisks = function (ng) {
            var protection = _this.protection(ng);
            return protection.calculs_risques();
        };
        _this.getServices = function (ng) {
            var protection = _this.protection(ng);
            return protection.calculs_services();
        };
        /**
         * Get the protection level. Can be 1 to 4, unknown is no need for protection.
         * undefined means that an analysis needs to be done
         * @param ng
         * @returns
         */
        _this.getTheoricalProtectionLevel = function (ng) {
            var protection = _this.protection(ng);
            return protection.calcul_protection_level();
        };
        _this.from(values);
        return _this;
    }
    Building.prototype.validAssets = function () {
        return distinctsAbstract(this.assets);
    };
    Building.prototype.validItems = function () {
        return distinctsAbstract(this.items, true) || [];
    };
    Building.prototype.validElectricalGroundings = function () {
        return distinctsAbstract(this.electricalGroundings, true) || [];
    };
    Building.prototype.validIncomingServices = function () {
        return distinctsAbstract(this.incomingServices, true) || [];
    };
    Building.prototype.color = function (index) {
        if (index < colors.length) {
            return colors[index];
        }
        return colors[colors.length % index];
    };
    Building.prototype.points = function () {
        var positions = [];
        try {
            var split_lat = (this.latitudes || "").split(",");
            var split_long = (this.longitudes || "").split(",");
            if (split_lat.length == split_long.length) {
                for (var i = 0; i < split_long.length; i++) {
                    var latitude = parseFloat(split_lat[i]);
                    var longitude = parseFloat(split_long[i]);
                    if (!isNaN(latitude) && !isNaN(longitude)) {
                        positions.push({ latitude: latitude, longitude: longitude });
                    }
                }
            }
            else {
                console.log("positions for building are incorrects");
            }
        }
        catch (e) {
            console.log("positions for building exception", e);
        }
        return positions;
    };
    Building.prototype.getDescriptionKeys = function (is_simulation) {
        return ["description", "width", "depth", "height"];
    };
    Building.prototype.getUnacceptableLoss = function () {
        return this.unacceptable_loss || ServiceType.NONE;
    };
    Building.prototype.setDelta = function (latitude, longitude) {
        this.delta_latitude_meter = latitude;
        this.delta_longitude_meter = longitude;
    };
    Building.prototype.deltaMeter = function () {
        return {
            latitude: this.delta_latitude_meter,
            longitude: this.delta_longitude_meter
        };
    };
    Building.prototype.deltaKm = function () {
        if (!this.delta_latitude_meter && !this.delta_longitude_meter)
            return {
                latitude: 0,
                longitude: 0
            };
        return {
            latitude: this.delta_latitude_meter * 1. / 1000,
            longitude: this.delta_longitude_meter * 1. / 1000
        };
    };
    __decorate([
        children(BuildingAsset),
        __metadata("design:type", Array)
    ], Building.prototype, "assets", void 0);
    __decorate([
        children(BuildingItem),
        __metadata("design:type", Array)
    ], Building.prototype, "items", void 0);
    __decorate([
        children(ElectricalGroundingComponent),
        __metadata("design:type", Array)
    ], Building.prototype, "electricalGroundings", void 0);
    __decorate([
        children(IncomingServiceComponent),
        __metadata("design:type", Array)
    ], Building.prototype, "incomingServices", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], Building.prototype, "name", void 0);
    __decorate([
        column({ type: TypeReal, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], Building.prototype, "height", void 0);
    __decorate([
        column({ type: TypeReal, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], Building.prototype, "width", void 0);
    __decorate([
        column({ type: TypeReal, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], Building.prototype, "depth", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", String)
    ], Building.prototype, "description", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull }),
        __metadata("design:type", Object)
    ], Building.prototype, "latitudes", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull }),
        __metadata("design:type", Object)
    ], Building.prototype, "longitudes", void 0);
    __decorate([
        column({ type: TypeStateType, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Number)
    ], Building.prototype, "state", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], Building.prototype, "state_description", void 0);
    __decorate([
        column({ type: TypeProtectionLevel, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Number)
    ], Building.prototype, "protection_level", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], Building.prototype, "environment_comment", void 0);
    __decorate([
        column({ type: TypeCd, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Number)
    ], Building.prototype, "cd", void 0);
    __decorate([
        column({ type: TypeRiskFire, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Number)
    ], Building.prototype, "risk_fire", void 0);
    __decorate([
        column({ type: TypeDanger, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Number)
    ], Building.prototype, "danger", void 0);
    __decorate([
        column({ type: TypeOccupation, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Number)
    ], Building.prototype, "occupation", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], Building.prototype, "service1_comment", void 0);
    __decorate([
        column({ type: TypeServiceEntrant, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Number)
    ], Building.prototype, "service1", void 0);
    __decorate([
        column({ type: TypeServiceType, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Number)
    ], Building.prototype, "service1_type", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], Building.prototype, "service2_comment", void 0);
    __decorate([
        column({ type: TypeServiceEntrant, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Number)
    ], Building.prototype, "service2", void 0);
    __decorate([
        column({ type: TypeServiceType, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Number)
    ], Building.prototype, "service2_type", void 0);
    __decorate([
        column({ type: TypeServiceType, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Number)
    ], Building.prototype, "unacceptable_loss", void 0);
    __decorate([
        column({ type: TypeReal, option: Argument.DefaultNull }),
        __metadata("design:type", Number)
    ], Building.prototype, "delta_latitude_meter", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull }),
        __metadata("design:type", Number)
    ], Building.prototype, "delta_longitude_meter", void 0);
    return Building;
}(Abstract));
export default Building;
//# sourceMappingURL=Building.js.map