import { Abstract } from "./Abstract";
import { UUIDable } from "../table/UUIDable";
import { MaterialType } from "../helpers/MaterialType";
import ConductorAsset from "./ConductorAsset";
import GroundingComponent from "./GroundingComponent";
import CounterComponent from "./CounterComponent";
import { DimensionType } from "../helpers/Dimension";
import { State } from "../helpers/State";
import ConductorSectionComponent from "./ConductorSectionComponent";
import { FixationComponent } from ".";
import { FailureObject } from "./FailureObject";
export interface ConductorComponentParams extends UUIDable {
    description: string;
    material: MaterialType;
    brand: string;
    state: State;
    state_description: string;
    dimension: DimensionType;
    date: Date;
    has_sign: boolean;
    has_sign_comment: string;
    joint_control: boolean;
    joint_control_comment: string;
    joint_control_marking: string;
    joint_control_state: State;
    has_protection_shield: boolean;
    has_protection_shield_comment: string;
    has_protection_shield_state: State;
    horizontal_equipotential_recovery: boolean;
    horizontal_equipotential_recovery_comment: string;
}
/**
 * The Component class will be a device for instance
 *   lpsfr uuid
 *   description
 *   etc...
 */
export default class ConductorComponent extends Abstract<ConductorComponentParams, ConductorComponent> implements FailureObject {
    private fixation?;
    counters: CounterComponent[];
    validCounters(): CounterComponent[];
    hasIssues(): boolean;
    hasIssuesOrChildrenIssues(): boolean;
    has_issues: boolean | undefined;
    has_issues_description: string | undefined;
    assets: ConductorAsset[];
    validAssets(): ConductorAsset[];
    groundings: GroundingComponent[];
    validGroundings(): GroundingComponent[];
    sections: ConductorSectionComponent[];
    validSections(): ConductorSectionComponent[];
    dimension: DimensionType | undefined;
    description: string | undefined;
    material: MaterialType | undefined;
    brand: string | undefined;
    has_counter: boolean | undefined;
    has_sign: boolean | undefined;
    has_sign_comment: string | undefined;
    joint_control: boolean | undefined;
    joint_control_comment: string | undefined;
    joint_control_marking: string | undefined;
    joint_control_state: State | undefined;
    has_protection_shield: boolean | undefined;
    has_protection_shield_comment: string | undefined;
    has_protection_shield_state: State | undefined;
    has_no_horizontal_support: boolean | undefined;
    path_as_straight_as_possible: boolean | undefined;
    path_as_straight_as_possible_comment: string | undefined;
    curve_respected: boolean | undefined;
    curve_respected_comment: string | undefined;
    state: State | undefined;
    state_description: string | undefined;
    horizontal_equipotential_recovery: boolean | undefined;
    horizontal_equipotential_recovery_comment: string | undefined;
    constructor(values: ConductorComponentParams);
    protected assets_key: () => string[];
    default_key: string | undefined;
    setFixation: (fixation: FixationComponent) => FixationComponent;
    verification_keys(): (keyof ConductorComponent)[];
    getDescriptionKeys(is_simulation?: boolean): (keyof ConductorComponent)[];
}
