import { Abstract } from "./Abstract";
import { UUIDable } from "../table/UUIDable";
import { State } from "../helpers/State";
import { Position } from "../../webservice/Weather";
import ConductorSectionAsset from "./ConductorSectionAsset";
import { FailureObject } from "./FailureObject";
export interface ConductorSectionComponentParams extends UUIDable {
    is_vertical: boolean;
    date: Date;
    has_no_horizontal_support?: boolean;
    horizontal_support: string;
    length_horizontal: number;
    horizontal_number_support_per_meter: number;
    horizontal_number_support_per_meter_state: State;
    horizontal_number_support_per_meter_state_comment: string;
    curve_respected: boolean;
    curve_respected_comment: string;
    horizontal_path_as_straight_as_possible: boolean;
    horizontal_path_as_straight_as_possible_comment: string;
    horizontal_equipotential_recovery: boolean;
    horizontal_equipotential_recovery_comment: string;
    vertical_support: string;
    length_vertical: number;
    vertical_number_support_per_meter: number;
    vertical_number_support_per_meter_state: State;
    vertical_number_support_per_meter_state_comment: string;
    path_as_straight_as_possible: boolean;
    path_as_straight_as_possible_comment: string;
    equipotential_recovery: boolean;
    equipotential_recovery_comment: string;
    length: number;
}
/**
 * The Component class will be a device for instance
 *   lpsfr uuid
 *   description
 *   etc...
 */
export default class ConductorSectionComponent extends Abstract<ConductorSectionComponentParams, ConductorSectionComponent> implements FailureObject {
    assets: ConductorSectionAsset[];
    has_issues: boolean | undefined;
    has_issues_description: string | undefined;
    hasIssues(): boolean;
    hasIssuesOrChildrenIssues(): boolean;
    validAssets(): ConductorSectionAsset[];
    is_vertical: boolean | undefined;
    state: State | undefined;
    state_description: string | undefined;
    latitudes: string | undefined;
    longitudes: string | undefined;
    support: string | undefined;
    number_support_per_meter: number | undefined;
    length: number | undefined;
    constructor(values: ConductorSectionComponentParams);
    points(): Position[];
    protected assets_key: () => string[];
    default_key: string | undefined;
    getDescriptionKeys(is_simulation?: boolean): (keyof ConductorSectionComponent)[];
}
