import { Abstract } from "./Abstract";
import { DisplayType } from "../helpers/DisplayType";
import { State } from "../helpers/State";
import { UUIDable } from "../table/UUIDable";
import CounterAsset from "./CounterAsset";
import { AlimentationType } from "../helpers/AlimentationType";
import { FailureObject } from "./FailureObject";
export interface CounterComponentParams extends UUIDable {
    brand?: string;
    display?: DisplayType;
    serial_number?: string;
    state?: State;
    description?: string;
    count?: number;
    has_memory?: boolean;
    alimentation?: AlimentationType;
    will_communicate?: boolean;
    date?: Date;
}
/**
 * The Component class will be a device for instance
 *   lpsfr uuid
 *   description
 *   etc...
 */
export default class CounterComponent extends Abstract<CounterComponentParams, CounterComponent> implements FailureObject {
    assets: CounterAsset[];
    validAssets(): CounterAsset[];
    hasIssues(): boolean;
    hasIssuesOrChildrenIssues(): boolean;
    has_issues: boolean | undefined;
    has_issues_description: string | undefined;
    serial_number: string | undefined;
    brand: string | undefined;
    description: string | undefined;
    display: DisplayType | undefined;
    alimentation: AlimentationType | undefined;
    count: number | undefined;
    state: State | undefined;
    has_memory: boolean | undefined;
    will_communicate: boolean | undefined;
    constructor(values: CounterComponentParams);
    protected assets_key: () => string[];
    getDescriptionKeys(is_simulation?: boolean): (keyof CounterComponent)[];
}
