import { Abstract } from "./Abstract";
import { UUIDable } from "../table/UUIDable";
import { Position } from "../../webservice/Weather";
import ElectricalGroundingAsset from "./ElectricalGroundingAsset";
import { MaterialStakeType } from "../helpers/MaterialStakeType";
import { MaterialShortType } from "../helpers/MaterialShortType";
import { FailureObject } from "./FailureObject";
export interface ElectricalGroundingComponentParams extends UUIDable {
    assets: ElectricalGroundingAsset[];
    name: string | undefined;
    latitudes: string | undefined;
    longitudes: string | undefined;
    section: string | undefined;
    material: MaterialShortType | undefined;
    has_stakes?: boolean;
    optional_stakes_height: number | undefined;
    optional_stakes_material?: MaterialStakeType;
    resistivity: number | undefined;
}
/**
 * The Component class will be a device for instance
 *   lpsfr uuid
 *   description
 *   etc...
 */
export default class ElectricalGroundingComponent extends Abstract<ElectricalGroundingComponentParams, ElectricalGroundingComponent> implements FailureObject {
    assets: ElectricalGroundingAsset[];
    validAssets(): ElectricalGroundingAsset[];
    hasIssues(): boolean;
    hasIssuesOrChildrenIssues(): boolean;
    has_issues: boolean | undefined;
    has_issues_description: string | undefined;
    name: string | undefined;
    latitudes: string | undefined;
    longitudes: string | undefined;
    section: string | undefined;
    material: MaterialShortType | undefined;
    has_stakes?: boolean;
    optional_stakes_height: number | undefined;
    optional_stakes_material?: MaterialStakeType;
    resistivity: number | undefined;
    constructor(values: ElectricalGroundingComponentParams);
    verification_keys(): (keyof ElectricalGroundingComponent)[];
    points(): Position[];
    protected assets_key: () => string[];
    getDescriptionKeys(is_simulation?: boolean): (keyof ElectricalGroundingComponent)[];
}
