import { Abstract } from "./Abstract";
import { UUIDable } from "../table/UUIDable";
import FixationAsset from "./FixationAsset";
import { SupportType } from "../helpers/SupportType";
import { State } from "../helpers/State";
import { FixationType } from "../helpers/FixationType";
import { MaterialSupportType } from "../helpers/MaterialSupportType";
import { FixationSupportType } from "../helpers/FixationSupportType";
import { FailureObject } from "./FailureObject";
export interface FixationComponentParams extends UUIDable {
    material?: MaterialSupportType;
    vertical?: boolean;
    state?: State;
    state_comment?: string;
    structure?: SupportType;
    structure_state?: State;
    structure_state_comment?: string;
    fixation_type?: FixationType;
    fixation_type_state?: State;
    fixation_type_state_comment?: string;
    fixation_support_type?: FixationSupportType;
    fixation_support_type_state?: State;
    fixation_support_type_state_comment?: string;
    is_conductor?: boolean;
    date?: Date;
}
/**
 * The Component class will be a device for instance
 *   lpsfr uuid
 *   description
 *   etc...
 */
export default class FixationComponent extends Abstract<FixationComponentParams, FixationComponent> implements FixationComponentParams, FailureObject {
    assets: FixationAsset[];
    validAssets(): FixationAsset[];
    hasIssues(): boolean;
    hasIssuesOrChildrenIssues(): boolean;
    has_issues: boolean | undefined;
    has_issues_description: string | undefined;
    fixation_type: FixationType | undefined;
    fixation_type_state: State | undefined;
    fixation_type_state_comment: string | undefined;
    fixation_support_type: FixationSupportType | undefined;
    fixation_material: MaterialSupportType | undefined;
    fixation_support_type_state: State | undefined;
    fixation_support_type_state_comment: string | undefined;
    structure: SupportType | undefined;
    structure_state: State | undefined;
    structure_state_comment: string | undefined;
    material: MaterialSupportType | undefined;
    vertical: boolean | undefined;
    state: State | undefined;
    state_comment: string | undefined;
    is_conductor: boolean | undefined;
    constructor(values: FixationComponentParams);
    is_ground: () => boolean;
    protected assets_key: () => string[];
    getDescriptionKeys(is_simulation?: boolean): (keyof FixationComponent)[];
}
