import { Abstract } from "./Abstract";
import { UUIDable } from "../table/UUIDable";
import { MaterialShortType } from "../helpers/MaterialShortType";
import GroundingAsset from "./GroundingAsset";
import { DimensionType } from "../helpers/Dimension";
import { GeometryType } from "../helpers/GeometryType";
import { Position } from "../../webservice/Weather";
import { MaterialStakeType } from "../helpers/MaterialStakeType";
import { MaterialStakeFixingType } from "../helpers/MaterialStakeFixingType";
import { MaterialStakeMeasureType } from "../helpers/MaterialStakeMeasureType";
import { FailureObject } from "./FailureObject";
export interface GroundingComponentParams extends UUIDable {
    material?: MaterialShortType;
    dimension?: DimensionType;
    dimension_comment?: string;
    brand?: string;
    geometry?: GeometryType;
    geometry_comment?: string;
    equipotential_recovery?: boolean;
    equipotential_recovery_comment?: string;
    resistivity?: number;
    optional_stakes_height?: number;
    optional_stakes_material?: MaterialStakeType;
    optional_stakes_fixing?: MaterialStakeFixingType;
    optional_stakes_measure?: MaterialStakeMeasureType;
    optional_manhole_start_grounding?: boolean;
    optional_manhole_each_rod?: boolean;
    optional_manhole_norm_markings?: boolean;
}
/**
 * The Component class will be a device for instance
 *   lpsfr uuid
 *   description
 *   etc...
 */
export default class GroundingComponent extends Abstract<GroundingComponentParams, GroundingComponent> implements FailureObject {
    assets: GroundingAsset[];
    validAssets(): GroundingAsset[];
    hasIssues(): boolean;
    hasIssuesOrChildrenIssues(): boolean;
    has_issues: boolean | undefined;
    has_issues_description: string | undefined;
    brand: string | undefined;
    geometry: GeometryType | undefined;
    geometry_comment: string | undefined;
    equipotential_recovery: boolean | undefined;
    equipotential_recovery_comment: string | undefined;
    material: MaterialShortType | undefined;
    material_comment: string | undefined;
    dimension: DimensionType | undefined;
    resistivity: number | undefined;
    latitudes: string | undefined;
    longitudes: string | undefined;
    optional_stakes_height: number | undefined;
    optional_stakes_material?: MaterialStakeType;
    optional_stakes_fixing?: MaterialStakeFixingType;
    optional_stakes_measure?: MaterialStakeMeasureType;
    optional_manhole_start_grounding?: boolean;
    optional_manhole_each_rod?: boolean;
    optional_manhole_norm_markings?: boolean;
    constructor(values: GroundingComponentParams);
    verification_keys(): (keyof GroundingComponent)[];
    points(): Position[];
    protected assets_key: () => string[];
    getDescriptionKeys(is_simulation?: boolean): (keyof GroundingComponent)[];
    isTriangle(): boolean;
    isSimplified(): boolean;
    isTriangleOrSimplified(): boolean;
}
