var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __spreadArrays = (this && this.__spreadArrays) || function () {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
};
import { Abstract } from "./Abstract";
import { Argument, TypeText, TypeReal, TypeBoolean } from "../helpers/Types";
import { children, column } from "../helpers/Decorators";
import { TypeMaterialShortType } from "../helpers/MaterialShortType";
import GroundingAsset from "./GroundingAsset";
import { TypeDimensionType, DimensionType } from "../helpers/Dimension";
import { GeometryType, TypeGeometryType } from "../helpers/GeometryType";
import { MaterialStakeType, TypeMaterialStakeType } from "../helpers/MaterialStakeType";
import { MaterialStakeFixingType, TypeMaterialStakeFixingType } from "../helpers/MaterialStakeFixingType";
import { MaterialStakeMeasureType, TypeMaterialStakeMeasureType } from "../helpers/MaterialStakeMeasureType";
import { distinctsAbstract } from "../../utils/Array";
/**
 * The Component class will be a device for instance
 *   lpsfr uuid
 *   description
 *   etc...
 */
var GroundingComponent = /** @class */ (function (_super) {
    __extends(GroundingComponent, _super);
    function GroundingComponent(values) {
        var _this = _super.call(this, "GroundingComponent", values) || this;
        _this.assets = [];
        _this.has_issues = false;
        _this.has_issues_description = "";
        _this.brand = undefined;
        _this.geometry = GeometryType.OTHER;
        //TODO add back?
        _this.geometry_comment = "";
        _this.equipotential_recovery = false;
        _this.equipotential_recovery_comment = "";
        _this.material = undefined;
        _this.material_comment = "";
        _this.dimension = DimensionType.TYPE_OTHER;
        _this.resistivity = undefined;
        _this.latitudes = "";
        _this.longitudes = "";
        _this.optional_stakes_height = 0;
        _this.optional_stakes_material = MaterialStakeType.UNKNOWN;
        _this.optional_stakes_fixing = MaterialStakeFixingType.UNKNOWN;
        _this.optional_stakes_measure = MaterialStakeMeasureType.UNKNOWN;
        _this.optional_manhole_start_grounding = false;
        _this.optional_manhole_each_rod = false;
        _this.optional_manhole_norm_markings = false;
        _this.assets_key = function () { return ["assets"]; };
        _this.from(values);
        return _this;
    }
    GroundingComponent.prototype.validAssets = function () {
        return distinctsAbstract(this.assets);
    };
    GroundingComponent.prototype.hasIssues = function () {
        return !!this.has_issues;
    };
    GroundingComponent.prototype.hasIssuesOrChildrenIssues = function () {
        return this.hasIssues();
    };
    GroundingComponent.prototype.verification_keys = function () {
        if (this.geometry == GeometryType.UNKNOWN) {
            var keys = [
                "geometry",
                "brand",
                "equipotential_recovery",
                "equipotential_recovery_comment",
                "resistivity"
            ];
            return keys;
        }
        return _super.prototype.verification_keys.call(this);
    };
    GroundingComponent.prototype.points = function () {
        var positions = [];
        try {
            var split_lat = (this.latitudes || "").split(",");
            var split_long = (this.longitudes || "").split(",");
            if (split_lat.length == split_long.length) {
                for (var i = 0; i < split_long.length; i++) {
                    var latitude = parseFloat(split_lat[i]);
                    var longitude = parseFloat(split_long[i]);
                    if (!isNaN(latitude) && !isNaN(longitude)) {
                        positions.push({ latitude: latitude, longitude: longitude });
                    }
                }
            }
            else {
                console.log("positions for building are incorrects");
            }
        }
        catch (e) {
            console.log("positions for building exception", e);
        }
        return positions;
    };
    GroundingComponent.prototype.getDescriptionKeys = function (is_simulation) {
        if (this.geometry == GeometryType.UNKNOWN) {
            if (is_simulation)
                return [];
            return [
                "brand",
                "equipotential_recovery_comment",
                "resistivity",
                "has_issues",
                "has_issues_description"
            ];
        }
        var array = [
            "dimension",
            "brand",
            "geometry_comment",
            "equipotential_recovery_comment"
        ];
        if (!is_simulation) {
            array = __spreadArrays(array, [
                "has_issues",
                "has_issues_description"
            ]);
        }
        var optionals = [
            "optional_stakes_material",
            "optional_stakes_fixing",
            "optional_stakes_measure",
            "optional_stakes_height",
            "optional_manhole_start_grounding",
            "optional_manhole_each_rod"
        ];
        if (!is_simulation)
            optionals.push("optional_manhole_norm_markings");
        if (this.isTriangleOrSimplified()) {
            array = __spreadArrays(array, optionals);
        }
        if (is_simulation)
            return array;
        return __spreadArrays(array, [
            "material_comment",
            "resistivity"
        ]);
    };
    GroundingComponent.prototype.isTriangle = function () {
        return !!(this.geometry == GeometryType.TRIANGLE);
    };
    GroundingComponent.prototype.isSimplified = function () {
        return !!(this.geometry == GeometryType.SIMPLIFIED);
    };
    GroundingComponent.prototype.isTriangleOrSimplified = function () {
        return this.isTriangle() || this.isSimplified();
    };
    __decorate([
        children(GroundingAsset),
        __metadata("design:type", Array)
    ], GroundingComponent.prototype, "assets", void 0);
    __decorate([
        column({ type: TypeBoolean, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "has_issues", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "has_issues_description", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "brand", void 0);
    __decorate([
        column({ type: TypeGeometryType, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "geometry", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "geometry_comment", void 0);
    __decorate([
        column({ type: TypeBoolean, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "equipotential_recovery", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "equipotential_recovery_comment", void 0);
    __decorate([
        column({ type: TypeMaterialShortType, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "material", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "material_comment", void 0);
    __decorate([
        column({ type: TypeDimensionType, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "dimension", void 0);
    __decorate([
        column({ type: TypeReal, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "resistivity", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "latitudes", void 0);
    __decorate([
        column({ type: TypeText, option: Argument.DefaultNull }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "longitudes", void 0);
    __decorate([
        column({ type: TypeReal, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Object)
    ], GroundingComponent.prototype, "optional_stakes_height", void 0);
    __decorate([
        column({ type: TypeMaterialStakeType, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", String)
    ], GroundingComponent.prototype, "optional_stakes_material", void 0);
    __decorate([
        column({ type: TypeMaterialStakeFixingType, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", String)
    ], GroundingComponent.prototype, "optional_stakes_fixing", void 0);
    __decorate([
        column({ type: TypeMaterialStakeMeasureType, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", String)
    ], GroundingComponent.prototype, "optional_stakes_measure", void 0);
    __decorate([
        column({ type: TypeBoolean, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Boolean)
    ], GroundingComponent.prototype, "optional_manhole_start_grounding", void 0);
    __decorate([
        column({ type: TypeBoolean, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Boolean)
    ], GroundingComponent.prototype, "optional_manhole_each_rod", void 0);
    __decorate([
        column({ type: TypeBoolean, option: Argument.DefaultNull, in_verification: true }),
        __metadata("design:type", Boolean)
    ], GroundingComponent.prototype, "optional_manhole_norm_markings", void 0);
    return GroundingComponent;
}(Abstract));
export default GroundingComponent;
//# sourceMappingURL=GroundingComponent.js.map