import { Abstract } from "./Abstract";
import InstallableComponent from "./InstallableComponent";
import InstallationAsset from "./InstallationAsset";
import { UUIDable } from "../table/UUIDable";
import ParatonnerreComponent from "./ParatonnerreComponent";
import StormDetectorComponent from "./StormDetectorComponent";
import { InstallationType } from "../helpers/InstallationType";
import { InstallationState } from "../helpers/InstallationState";
import SurgeArresterComponent from "./SurgeArresterComponent";
import EquipotentialRecoveryComponent from "./EquipotentialRecoveryComponent";
import { FailureObject, FailureObjectFields } from "./FailureObject";
export interface InstallationParams extends UUIDable, FailureObjectFields {
    description?: string;
    latitude?: number;
    longitude?: number;
    mode?: InstallationType;
    state: InstallationState;
    building?: string;
}
export default class Installation extends Abstract<InstallationParams, Installation> implements InstallationParams, FailureObject {
    components: InstallableComponent[];
    validComponents(): InstallableComponent[];
    assets: InstallationAsset[];
    validAssets(): InstallationAsset[];
    hasIssues(): boolean;
    hasIssuesOrChildrenIssues(): boolean;
    has_issues: boolean | undefined;
    has_issues_description: string | undefined;
    name: string;
    address: string;
    description: string;
    building: string;
    latitude: number;
    longitude: number;
    paratonnerres: ParatonnerreComponent[];
    validParatonnerres(): ParatonnerreComponent[];
    stormDetectors: StormDetectorComponent[];
    validStormDetectors(): StormDetectorComponent[];
    surgeArresters: SurgeArresterComponent[];
    validSurgeArresters(): SurgeArresterComponent[];
    equipotentialRecoveries: EquipotentialRecoveryComponent[];
    validEquipotentialRecoveries(): EquipotentialRecoveryComponent[];
    mode: InstallationType;
    state: InstallationState;
    constructor(values: InstallationParams);
    getState(): InstallationState;
    getType(): InstallationType;
    getDescriptionKeys(is_simulation?: boolean): (keyof Installation)[];
    protected assets_key: () => string[];
}
