import { Abstract } from "./Abstract";
import { UUIDable } from "../table/UUIDable";
import { CommunicationType } from "./Device";
import { ParatonnerreType } from "../helpers/MaterialType";
import ParatonnerreAsset from "./ParatonnerreAsset";
import FixationComponent from "./FixationComponent";
import ConductorComponent from "./ConductorComponent";
import { DeclaredParatonnerreType } from "../helpers/DeclaredParatonnerreType";
import { State } from "../helpers/State";
import { DeclaredRadioactiveParatonnerreType } from "../helpers/DeclaredRadioactiveParatonnerreType";
import { MaterialLightningRodType } from "../helpers/MaterialLightningRodType";
import { LightningRodType } from "../helpers/LightningRodType";
import { FailureObject, FailureObjectFields } from "./FailureObject";
export interface ParatonnerreComponentParams extends UUIDable, FailureObjectFields {
    building_item_uuid?: string;
    serial_number?: string;
    paratonnerre_type?: DeclaredParatonnerreType;
    radioactive_type?: DeclaredRadioactiveParatonnerreType;
    brand?: string;
    model?: string;
    communicationType?: CommunicationType;
    height?: string;
    material?: ParatonnerreType | undefined;
    diameter?: string;
    description?: string;
    height_to_the_protected_structure?: number;
    diameter_to_tip?: number;
    state?: State;
    state_comment?: string;
    lightning_rod_material_type?: MaterialLightningRodType;
    lightning_rod_comment?: string;
    lightning_rod_type?: LightningRodType;
    physical_connection_state?: State;
    physical_connection_state_comment?: string;
    ahead_to_boot_us?: number;
}
export interface PDA extends FailureObjectFields {
    building_item_uuid?: string;
    brand: string;
    model: string;
    serial_number: string;
    ahead_to_boot_us: number;
    height_to_the_protected_structure: number;
    state: State;
    state_comment: string;
    physical_connection_state?: State;
    physical_connection_state_comment?: string;
    date: Date;
    assets: ParatonnerreAsset[];
    fixations: FixationComponent[];
    conductors: ConductorComponent[];
    description?: string;
}
export interface UnknownParatonnerre extends FailureObjectFields {
    building_item_uuid?: string;
    height_to_the_protected_structure: number;
    diameter_to_tip: number;
    state: State;
    state_comment: string;
    date: Date;
    lightning_rod_comment?: string;
    physical_connection_state?: State;
    physical_connection_state_comment?: string;
    assets: ParatonnerreAsset[];
    fixations: FixationComponent[];
    conductors: ConductorComponent[];
    description?: string;
}
export interface SimpleParatonnerre extends FailureObjectFields {
    building_item_uuid?: string;
    material: ParatonnerreType;
    height_to_the_protected_structure: number;
    diameter_to_tip: number;
    state: State;
    state_comment: string;
    date: Date;
    lightning_rod_material_type?: MaterialLightningRodType;
    lightning_rod_comment?: string;
    lightning_rod_type?: LightningRodType;
    physical_connection_state?: State;
    physical_connection_state_comment?: string;
    assets: ParatonnerreAsset[];
    fixations: FixationComponent[];
    conductors: ConductorComponent[];
    description?: string;
}
/**
 * The Component class will be a device for instance
 *   lpsfr uuid
 *   description
 *   etc...
 */
export default class ParatonnerreComponent extends Abstract<ParatonnerreComponentParams, ParatonnerreComponent> implements FailureObject {
    assets: ParatonnerreAsset[];
    validAssets(): ParatonnerreAsset[];
    hasIssues(): boolean;
    hasIssuesOrChildrenIssues(): boolean;
    fixations: FixationComponent[];
    validFixations(): FixationComponent[];
    conductors: ConductorComponent[];
    validConductors(): ConductorComponent[];
    has_issues: boolean | undefined;
    has_issues_description: string | undefined;
    serial_number: string;
    paratonnerre_type: DeclaredParatonnerreType;
    radioactive_type: DeclaredRadioactiveParatonnerreType;
    brand: string;
    building_item_uuid: string;
    model: string;
    communicationType: CommunicationType;
    height: string;
    material: ParatonnerreType | undefined;
    diameter: string;
    description: string;
    height_to_the_protected_structure: number | undefined;
    diameter_to_tip: number | undefined;
    state: State | undefined;
    state_comment: string;
    ahead_to_boot_us: number;
    physical_connection_state: State | undefined;
    physical_connection_state_comment: string;
    lightning_rod_material_type: MaterialLightningRodType | undefined;
    lightning_rod_type: LightningRodType | undefined;
    lightning_rod_comment: string;
    will_communicate: boolean | undefined;
    constructor(values: ParatonnerreComponentParams);
    protected keys(): (keyof ParatonnerreComponent)[];
    protected assets_key: () => string[];
    verification_keys(): (keyof ParatonnerreComponent)[];
    private specificVerificationKeys;
    getAsPDA(): PDA;
    getAsUnknown(): UnknownParatonnerre;
    getAsSimpleParatonnerre(): SimpleParatonnerre;
    getCommunicationType(): CommunicationType;
    default_key: keyof ParatonnerreComponent;
    getDescriptionKeys(is_simulation?: boolean): (keyof ParatonnerreComponent)[];
}
