import { Abstract, GenericInterface } from "./Abstract";
import Installation from "./Installation";
import ProjectAsset from "./ProjectAsset";
import { UUIDable } from "../table/UUIDable";
import { InstallationState } from "../helpers/InstallationState";
import Building from "./Building";
import Bridge from "./Bridge";
import { ProtectionLevel } from "../helpers/ProtectionLevel";
import DbDescriptor, { BindTogether } from "../table/DbDescriptor";
import { FailureObject, FailureObjectFields } from "./FailureObject";
export interface ProjectInterface extends UUIDable, FailureObjectFields {
    name?: string;
    address?: string;
    description?: string;
    contact_name?: string;
    contact_phone?: string;
    contact_email?: string;
    contact_status?: string;
    longitude?: number;
    latitude?: number;
    to_sync?: boolean;
    push_notification_start_at?: number;
    push_notification_stop_at?: number;
    local_user_id?: number;
    delta_latitude_meter?: number;
    delta_longitude_meter?: number;
}
export interface VerificationParams extends UUIDable, FailureObjectFields {
    date: Date;
    user: string;
    validated: boolean;
    started_at_optional?: Date;
    validated_date?: Date;
    validated_text?: string;
    is_simulation?: boolean;
}
export declare class Verification extends Abstract<VerificationParams, Verification> implements FailureObject {
    projects: Project[];
    validProjects(): Project[];
    assets: any[];
    validAssets(): any[];
    hasIssues(): boolean;
    hasIssuesOrChildrenIssues(): boolean;
    has_issues: boolean | undefined;
    has_issues_description: string | undefined;
    user: string;
    validated: boolean | undefined;
    validated_date: Date | undefined;
    started_at_optional: Date | undefined;
    validated_text: string | undefined;
    is_simulation: boolean | undefined;
    constructor(values: VerificationParams);
    full_json(include_local?: boolean, exclude_assets?: boolean): any;
    save(recursive?: boolean): Promise<this>;
    project(): Project | null;
    populate: () => Promise<Verification>;
    init(instance: any): DbDescriptor;
    protected annotated_children(): BindTogether<GenericInterface<Abstract<any, any>>>[];
}
export declare class Project extends Abstract<ProjectInterface, Project> implements FailureObject {
    hasIssues(): boolean;
    hasIssuesOrChildrenIssues(): boolean;
    has_issues: boolean | undefined;
    has_issues_description: string | undefined;
    maintenance_interval: string;
    name: string;
    address: string;
    description: string;
    longitude: number;
    latitude: number;
    countryCode: string;
    adminArea: string;
    to_sync: boolean;
    last_message_server: Date | undefined;
    registered_devices: string | undefined;
    push_notification_start_at?: number;
    push_notification_stop_at?: number;
    local_user_id?: number;
    contact_name: string;
    contact_email: string;
    contact_status: string;
    contact_phone: string;
    delta_latitude_meter: number;
    delta_longitude_meter: number;
    buildings: Building[];
    validBuildings(): Building[];
    bridges: Bridge[];
    validBridges(): Bridge[];
    installations: Installation[];
    validInstallations(): Installation[];
    verifications: Verification[];
    validVerifications(): Verification[];
    validSimulations(): Verification[];
    assets: ProjectAsset[];
    validAssets(): ProjectAsset[];
    protection_level: ProtectionLevel;
    language: string;
    constructor(values?: ProjectInterface);
    lang(): "en" | "fr" | "es" | "pt";
    checkPush(): void;
    valid_devices(): string[];
    calculate_protection_level(ng: number): ProtectionLevel;
    state(): InstallationState;
    clone(): any;
    protected assets_key: () => string[];
    private is_simulation;
    setSimulation(is_simulation?: boolean): void;
    isSimulation(): boolean;
    populate: () => Promise<Project>;
    init(instance: any): DbDescriptor;
    protected annotated_columns(): BindTogether<import("../helpers/Types").ColumnAnnotation>[];
    protected annotated_children(): BindTogether<GenericInterface<Abstract<any, any>>>[];
    setDelta(latitude: number, longitude: number): void;
    deltaMeter(): {
        latitude: number;
        longitude: number;
    };
    deltaKm(): {
        latitude: number;
        longitude: number;
    };
}
