import { GenericInterface, Abstract } from './../db/models/Abstract';
import ConfigManager from './ConfigManager';
import { UUIDable } from '../db/table/UUIDable';
import { Transaction } from 'react-native-sqlite-storage';
export interface GenericParameterInterface<UUIDABLE extends UUIDable, T extends Abstract<UUIDABLE, T>> extends GenericInterface<T> {
    new (param: UUIDABLE): T;
}
export default class ProjectDatabase {
    private config_manager;
    private helper;
    private descriptors;
    constructor(config_manager: ConfigManager);
    init(optional_models?: GenericInterface<any>[]): Promise<boolean>;
    drops(optional_models?: GenericInterface<any>[]): Promise<boolean>;
    /**
     * Instantiate - does not save, an instance of a given Klass
     * @param param the json representing data to populate the object
     * @param klass the reprenting holding Class of the holder of the data
     */
    instantiate<UUIDABLE extends UUIDable, T extends Abstract<UUIDABLE, T>>(param: UUIDABLE, klass: GenericParameterInterface<UUIDABLE, T>): T;
    populate<UUIDABLE extends UUIDable, T extends Abstract<UUIDABLE, T>>(instance: T): Promise<T>;
    select<T extends Abstract<UUIDable, T>, K extends GenericInterface<T>>(klass: K, id: number): Promise<T | undefined>;
    selectChildren<T extends Abstract<UUIDable, T>, K extends GenericInterface<T>>(klass: K, parent_id: number): Promise<T[]>;
    selectFromUUID<T extends Abstract<UUIDable, T>, K extends GenericInterface<T>>(klass: K, uuid: string): Promise<T | undefined>;
    list<T extends Abstract<UUIDable, T>, K extends GenericInterface<T>>(klass: K): Promise<T[]>;
    fetchFromDatabase<T extends Abstract<UUIDable, T>, K extends GenericInterface<T>>(transaction: Transaction, klass: K): Promise<T[]>;
    private log;
    private drop;
    private selectListFromGivenKey;
    private selectFromGivenKey;
    deleteMessage<T extends Abstract<UUIDable, T>>(message: T): Promise<boolean | undefined>;
    private rows;
    private missing_date_fields;
    private creation;
    private migrate;
    private indexes;
    private reject;
    private descriptor;
}
