var Queue = /** @class */ (function () {
    function Queue(delay, queue_length) {
        if (delay === void 0) { delay = 1; }
        if (queue_length === void 0) { queue_length = -1; }
        this.delay = delay;
        this.queue_length = queue_length;
        this.waiting = [];
        this.waiting_for_one_call = false;
    }
    Queue.prototype.next = function () {
        var _this = this;
        if (this.waiting.length > 0) {
            this.waiting_for_one_call = true;
            var item = this.waiting.shift();
            if (!item) {
                this.waiting_for_one_call = false;
            }
            else {
                var provider = item.provider, resolve_1 = item.resolve, reject_1 = item.reject;
                var promise = provider();
                if (!promise) {
                    reject_1(new Error("invalid promise obtained from provider call!"));
                }
                promise.then(function (data) {
                    resolve_1(data);
                    setTimeout(function () { return _this.next(); }, _this.delay);
                }).catch(function (e) {
                    reject_1(e);
                    setTimeout(function () { return _this.next(); }, _this.delay);
                });
            }
        }
        else {
            this.waiting_for_one_call = false;
        }
    };
    Queue.prototype.isRunning = function () {
        return this.waiting_for_one_call;
    };
    Queue.prototype.enqueue = function (provider) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this.queue_length > 0 && _this.waiting.length >= _this.queue_length) {
                return reject("discarding call");
            }
            _this.waiting.push({ provider: provider, resolve: resolve, reject: reject });
            if (!_this.waiting_for_one_call) {
                _this.next();
            }
        });
    };
    Queue.prototype.enqueuePromise = function (lambda) {
        return this.enqueue(function () { return new Promise(lambda); });
    };
    return Queue;
}());
export default Queue;
//# sourceMappingURL=queue.js.map