import LocalDevice from "../managers/LocalDevice";
import { Position, WeatherData } from "./Weather";
import { MessageParams } from '../db/models/Message';
import { Moment } from 'moment';
import { RoutairDiagnostic } from './RoutairDiagnostic';
import { User } from '../db/models';
import UploadInterface from "./UploadInterface";
import { DownloadBeginCallbackResult, DownloadFileOptions, DownloadFileResult, DownloadProgressCallbackResult } from "./Download";
export interface UploadedFileInfo {
    name: string;
    key: string;
    mimetype: string;
    size: number;
}
export interface IAPHubActiveProducts {
    id: string;
    type: string;
    sku: string;
    platform: "ios" | "android";
    purchase: string;
    purchaseDate: string;
    group?: string;
    groupName?: string;
    expirationDate?: string;
    autoResumeDate?: string;
    androidToken?: string;
    isSubscriptionRenewable?: boolean;
    isSubscriptionRetryPeriod?: boolean;
    subscriptionState?: "active" | "grace_period" | "retry_period" | "paused";
    subscriptionPeriodType?: "normal" | "intro" | "trial";
}
export interface IAPHubUser {
    tags: any[];
    activeProducts: IAPHubActiveProducts[];
}
export interface ApiRegisterDeviceProject {
    project: string;
    device: string;
}
export interface ApiRegisterAnswer extends ApiRegisterDeviceProject {
    added: boolean;
}
export interface AlertDay {
    timestamp: number;
    sent: boolean;
    value: string;
    yymmdd: number;
    type: "wind" | "temperature";
}
export interface ProjectAlert {
    project: string;
    alert: AlertDay;
    count: number;
}
export interface DayHolder {
    yymmdd: number;
    date: Moment;
    alerts: ProjectAlert[];
}
export interface ApiRegisterDeviceProjectResult {
    unknown: string[];
    added: ApiRegisterAnswer[];
}
export interface Company {
    company_name: string;
    company_address: string;
    company_city: string;
    company_postal_code: string;
    company_country: string;
    company_website: string;
}
export interface PublicProfile {
    gmt: string;
    guid: string;
    lastname?: string;
    name?: string;
    surname?: string;
    website?: string;
    firstname?: string;
    business?: Company;
}
export interface Conversation {
    uuid: string;
    participants: PublicProfile[];
    updated_at: Date;
    videoCall: boolean;
}
export interface LightDevice {
    id: number;
    serial: string;
    internal_serial: string;
    product_id: number;
    latitude: number;
    longitude: number;
}
export declare class LightApi {
    _env: string;
    constructor(env: string);
    register(localDevice: LocalDevice, push_token: string): Promise<any>;
    device(code: string): Promise<LightDevice | undefined>;
    add(localDevice: LocalDevice, code: string): Promise<any>;
    devices(localDevice: LocalDevice): Promise<any>;
}
export declare class SyncApi {
    private Upload;
    private downloadFile;
    downloadStop: (jobId: number) => void;
    private root;
    private _verification_readonly;
    private _upload;
    private _upload_conversation_put;
    private _upload_conversation_get;
    private _avatar;
    private _company_logo;
    private _avatar_public;
    private _company_logo_public;
    _persistence_token: string;
    _env: string;
    constructor(env: string, Upload: UploadInterface, downloadFile: (options: DownloadFileOptions) => DownloadFileResult, downloadStop: (jobId: number) => void);
    readonly(project: string, verification: string): Promise<any>;
    videoCallToken(): Promise<any>;
    videoCallInformaton(conversation: string): Promise<any>;
    avatarURL(user: User): string;
    companyLogo(user: User): string;
    refreshProjects(): Promise<any>;
    setAuthToken: (persistence_token: string) => string;
    clear: () => Promise<any>;
    setCompany: (company: Company) => Promise<Company>;
    getCompany: () => Promise<Company | {}>;
    getVersion: (project: string, version: string) => Promise<any>;
    getLastVersion: (project: string) => Promise<any>;
    getVersions: (project: string) => Promise<any>;
    getMaintenance: (project: string, date?: Date | undefined) => Promise<any>;
    putMaintenance: (project: string, message: MessageParams) => Promise<MessageParams>;
    putVersion: (project: string, content: any) => Promise<any>;
    getProjects: () => Promise<any>;
    getConversations(): Promise<Conversation[]>;
    createConversation(participants: string[]): Promise<Conversation>;
    getMessages(conversation: string): Promise<MessageParams[]>;
    putMessage(conversation: string, message: string): Promise<MessageParams[]>;
    getRights: (project: string) => Promise<any>;
    addRight: (project: string, user: string) => Promise<any>;
    project_files(project: string): Promise<UploadedFileInfo[]>;
    project_download_file(project: string, toFile: string, key: string, begin: (res: DownloadBeginCallbackResult) => void, progress: (res: DownloadProgressCallbackResult) => void): DownloadFileResult;
    downloadCertificate(serial: string, toFile: string, begin: (res: DownloadBeginCallbackResult) => void, progress: (res: DownloadProgressCallbackResult) => void): DownloadFileResult;
    downloadWarranty(serial: string, toFile: string, begin: (res: DownloadBeginCallbackResult) => void, progress: (res: DownloadProgressCallbackResult) => void): DownloadFileResult;
    project_upload_file(project: string, local_path: string, key: string, mimetype: string, on_progress: (progress: number) => void): Promise<unknown>;
    uploadAvatar(local_path: string, mimetype: string, on_progress: (progress: number) => void): Promise<unknown>;
    uploadCompanyLogo(local_path: string, mimetype: string, on_progress: (progress: number) => void): Promise<unknown>;
    upload(local_path: string, key: string, mimetype: string, on_progress: (progress: number) => void): Promise<unknown>;
    uploadFile(local_path: string, key: string, mimetype: string, on_progress: (progress: number) => void): Promise<unknown>;
    conversationUploadPut(conversation: Conversation, local_path: string, mimetype: string, on_progress: (progress: number) => void): Promise<unknown>;
    conversationUploadGet(conversation: Conversation, key: string): string;
    private uploadInternal;
}
/**
 * timestamp, sunrise and sunset needs to be multiplied by 1000
 */
interface WeatherFlat {
    project?: string;
    timestamp?: number;
    sunset?: number;
    surise?: number;
    temp?: number;
    feels_like?: number;
    temp_min?: number;
    temp_max?: number;
    pressure?: number;
    humidity?: number;
    clouds_desc?: string;
    clouds_id?: number;
    clouds_icon?: number;
    clouds_all?: number;
    wind_speed?: number;
    wind_deg?: number;
    latitude?: number;
    longitude?: number;
    created_at?: Date;
    hour?: number;
}
interface WeatherReportMonth {
    thunder: ({
        created_at?: Date;
        latitude?: number;
        longitude?: number;
        proejct?: string;
    })[];
    weather: WeatherFlat[];
}
interface StatsHour {
    numbers: number;
    yymmddhh: number;
    rssi: number;
    read_error: number;
}
export default class Api {
    _env: string;
    _persistence_token: string;
    _light: LightApi;
    sync: SyncApi;
    constructor(env: string, Upload: UploadInterface, downloadFile: (options: DownloadFileOptions) => DownloadFileResult, downloadStop: (jobId: number) => void);
    light: () => LightApi;
    setAuthToken(persistence_token: string): void;
    report(): Promise<any[] | null>;
    report_thunder(project: string): Promise<any[] | null>;
    report_weather(project: string): Promise<any[] | null>;
    report_routair_data(routair: string, left: Moment, right: Moment): Promise<RoutairDiagnostic[]>;
    report_weather_month(project: string, left: Moment, right: Moment): Promise<WeatherReportMonth>;
    report_weather_day(project: string, date: string): Promise<WeatherReportMonth>;
    report_alerts_month(project: string, left: Moment, right: Moment): Promise<AlertDay[]>;
    report_score(left: Moment, right: Moment, project: string): Promise<{
        score: number;
    }>;
    report_alerts_day_all(left: Moment, right: Moment, utcOffset?: number): Promise<DayHolder[]>;
    report_alerts_day_project(project: string, left: Moment, right: Moment, utcOffset?: number): Promise<DayHolder[]>;
    report_device_month(project: string, device: string, year: number, month: number): Promise<StatsHour[]>;
    register_devices(register: ApiRegisterDeviceProject[]): Promise<ApiRegisterDeviceProjectResult>;
    project_personnalisations_list(project: string): Promise<PublicProfile[]>;
    project_personnalisations_status(project: string): Promise<{
        status: "already" | "not";
        is_pro: boolean;
    }>;
    project_personnalisations_enable(project: string): Promise<{
        status: "already" | "ok";
    }>;
    report_device(id: string): Promise<any[] | null>;
    logs(id: string): Promise<any[] | null>;
    weather(position: Position): Promise<WeatherData | undefined>;
    login(login: string, password: string): Promise<any>;
    register(login: string, email: string, password: string): Promise<any>;
    profile: () => Promise<any>;
    iaps: () => Promise<IAPHubUser>;
    gemsTo1Giga: () => Promise<any>;
    gemsTo10Giga: () => Promise<any>;
    registry: () => Promise<PublicProfile[]>;
    updateToken(push_token: string, platform: string): Promise<any>;
    updateProfile(json: any): Promise<any>;
    devices(): Promise<any>;
    env(): string;
}
export {};
